@@ -87,6 +87,8 @@ c
        dk1   = getsca('dk1',1)
        dk2   = getsca('dk2',1)
        xidat = getsca('data_set',1)
+       pdfwgt = zero
+       pdfwgt= getsca('entropy_weight',1)
        idata = int(xidat)
        if (idata.le.0) idata = 1
        xidat = getsca('data_total',1)
@@ -108,7 +110,7 @@ c  interpret any and all keyword/value pairs for setting options
        do_mag = .false.
        do_pha = .false.
        do_bkg = .false.
-          
+       iftout = 0
        nqw = 0
        qw_tmp(1) = getsca('kweight',1)
        do 10 i = 2, mqwfs
@@ -157,6 +159,9 @@ cc                print*,  nrest_tmp, values(i)(:60)
              ier = iff_eval_dp(values(i), xkmax)
           elseif ((keys(i).eq.'kmin')) then
              ier = iff_eval_dp(values(i), xkmin)
+          elseif ((keys(i).eq.'entropy_weight')) then
+             ier = iff_eval_dp(values(i), pdfwgt)
+
           elseif ((keys(i).eq.'error_step')) then
              ier = iff_eval_in(values(i), nerstp)
           elseif ((keys(i).eq.'error_print')) then
@@ -214,6 +219,8 @@ cc                print*,  nrest_tmp, values(i)(:60)
              call str2lg(values(i), do_bkg, ier)
           elseif ((keys(i).eq.'toler')) then
              ier = iff_eval_dp(values(i), toler)
+          elseif (keys(i).eq.'ftout') then
+             ier = iff_eval_in(values(i),iftout)
 c
 c path list:
           elseif (values(i).eq.undef) then
@@ -402,8 +409,10 @@ c    determine eps_k/eps_r for this k-weight
 c    call 'chieps ('chi_noise' command) to get eps_k / eps_r
           if ((eps_k .le. epsmin).and.(eps_r .le. epsmin)) then 
              ilen = istrln(nam_chi(idata))
- 405         format('  chi=',a,',kmin=',f12.3,',kmax=',f12.3,
-     $            ',kweight=',f12.3,',dk1=',f12.3,',dk2=',f12.3)
+ 405         format('  chi=',a,',kmin=',f10.6,',kmax=',f10.6,
+     $            ',kweight=',f10.6,',dk1=',f10.6,
+     $            ',dk2=',f10.6)   
+cccc ,',ftout=',i3)
              write(cmdstr, 405) nam_chi(idata)(1:ilen),
      $            xkmin, xkmax,xkw,dk1,dk2
              if (nam_x(idata) .ne. undef) then
@@ -411,6 +420,7 @@ c    call 'chieps ('chi_noise' command) to get eps_k / eps_r
                 j2 = istrln(nam_x(idata))
                 cmdstr = cmdstr(:j0)//', k='//nam_x(idata)(:j2)
              endif
+ccc             print*, 'feffit : chi_noise ', cmdstr(:256)
              call iff_chieps(cmdstr)
              sigdtk  = getsca('epsilon_k',1)
              sigdtr  = getsca('epsilon_r',1)
@@ -539,7 +549,7 @@ c   call lmdif1 and fiterr
 
        
        do 580 idx = 1, nfdats
-          mfit = mfit + (nfit(idx) + nrestraint(idx))* nqwfs(idx)
+          mfit = mfit + (nfit(idx) + 1 + nrestraint(idx))* nqwfs(idx)
  580   continue 
        mfit = min(mfit, lenfvc)
 cc       print*, '  Feffit ', mfit, idx, nfit(idx), nqwfs(idx), nfdats,
