@@ -982,25 +982,28 @@ c  end subroutine boxcar_interp
        subroutine res_penalty(x0, nx0, x1, nx1, x2, nx2)
 
        include 'maxpts.h'
-       integer    nx0, nx1, nx2
+       integer    nx0, nx1, nx2, i
        double precision  x0(*), x1(*), x2(*)
        double precision xlo, xhi
 
        xlo = x1(1)
        xhi = x0(1)
        
-cc       print*, 'bound  xlo, xhi = [ ', xlo, ' : ', xhi, ' ]'
-cc       print*, 'bound  x = ', x2(1)
+cc       print*, 'bound  xlo, xhi = [ ', xlo, ' : ',xhi,' ]'
+cc       print*, 'bound  x = ', x2(1), nx2, nx1, nx0
 
-       if ((x2(1).ge.xlo) .and. (x2(1).le.xhi)) then
-          x0(1) = 0
-       elseif (x2(1).gt.xlo) then
-          x0(1) = abs(x2(1) - xhi)
-       elseif (x2(1).lt.xlo) then
-          x0(1) = abs(x2(1) - xlo)
-       endif
+       do 10 i = 1, nx2 
+          if ((x2(i).ge.xlo) .and. (x2(i).le.xhi)) then
+             x0(i) = 0
+          elseif (x2(i).gt.xlo) then
+             x0(i) = abs(x2(i) - xhi)
+          elseif (x2(i).lt.xlo) then
+             x0(i) = abs(x2(i) - xlo)
+          endif
+ 10    continue 
+       nx0 = nx2
+cc       print*, 'bound  penalty = ', x0(1), nx0
 
-cc     print*, 'bound  penalty = ', x0(1)
        return
        end
 
